==> nextcloud-app-deck-1%3A1.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/zh_TW.js <==
OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "您已建立新的佈告欄 {board}",
    "{user} has created a new board {board}" : "{user} 已建立新的佈告欄  {board}",
    "You have deleted the board {board}" : "您已刪除佈告欄 {board}",
    "{user} has deleted the board {board}" : "{user} 已刪除佈告欄{board}",
    "You have restored the board {board}" : "您已還原佈告欄{board}",
    "{user} has restored the board {board}" : "{user}已還原佈告欄{board}",
    "You have shared the board {board} with {acl}" : "您已和{acl}分享佈告欄{board}",
    "{user} has shared the board {board} with {acl}" : "{user} 已和{acl}分享佈告欄{board}",
    "Personal" : "私人的",
    "Finished" : "已完成",
    "Later" : "稍後",
    "copy" : "複製",
    "Done" : "完成",
    "The file was uploaded" : "檔案已上傳",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 的限制",
    "No file was uploaded" : "沒有檔案被上傳",
    "Missing a temporary folder" : "找不到暫存資料夾",
    "Could not write file to disk" : "寫入硬碟失敗",
    "A PHP extension stopped the file upload" : "一個 PHP 擴充功能終止檔案的上傳",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck是一種看板式組織工具，旨在針對與Nextcloud集成的團隊進行個人計劃和項目組織。\n\n\n- 📥 增加您的任務到card和把它們整理好\n- 📄 寫下額外的筆記在markdown\n- 🔖 分配標籤以更好地組織\n- 👥 與您的團隊，朋友或家人分享\n- 📎 附加檔案並將其嵌入到您的 markdown 描述\n- 💬 使用評論與您的團隊討論\n- ⚡ 跟踪變化在活動流程中\n- 🚀 取得您的專案組織",
    "Cancel" : "取消",
    "File already exists" : "檔案已存在",
    "Add new list" : "新增清單",
    "Details" : "詳細資料",
    "Sharing" : "分享",
    "Tags" : "標籤",
    "Deleted items" : "刪除的項目",
    "Timeline" : "時間軸",
    "Undo" : "復原",
    "Can edit" : "可以編輯",
    "Can share" : "可以分享",
    "Delete" : "刪除",
    "Delete list" : "刪除清單",
    "Add card" : "增加卡片",
    "Edit" : "編輯",
    "Assign to users" : "分派給使用者",
    "Due date" : "截止日",
    "Description" : "描述",
    "Attachments" : "附件",
    "Comments" : "意見",
    "Modified" : "已修改",
    "Created" : "已新增",
    "Upload attachment" : "上傳附件",
    "Save" : "儲存",
    "Reply" : "回覆",
    "Update" : "更新",
    "(group)" : "(群組)",
    "seconds ago" : "幾秒前",
    "Assign to me" : "分派給我",
    "Delete card" : "刪除作業",
    "Move card" : "移動卡片",
    "Settings" : "設定",
    "Share" : "分享",
    "Options" : "設定",
    "Edit board" : "編輯專案",
    "An error occurred" : "發生錯誤",
    "Archive board" : "封存的專案",
    "Delete board" : "刪除的專案",
    "Link to a board" : "連結到佈告欄",
    "Maximum file size of {size} exceeded" : "達到最大的檔案大小 {size} "
},
"nplurals=1; plural=0;");

==> nextcloud-app-deck-1%3A1.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/zh_TW.js <==
OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "您已建立新的佈告欄 {board}",
    "{user} has created a new board {board}" : "{user} 已建立新的佈告欄  {board}",
    "You have deleted the board {board}" : "您已刪除佈告欄 {board}",
    "{user} has deleted the board {board}" : "{user} 已刪除佈告欄{board}",
    "You have restored the board {board}" : "您已還原佈告欄{board}",
    "{user} has restored the board {board}" : "{user}已還原佈告欄{board}",
    "You have shared the board {board} with {acl}" : "您已和{acl}分享佈告欄{board}",
    "{user} has shared the board {board} with {acl}" : "{user} 已和{acl}分享佈告欄{board}",
    "Personal" : "私人的",
    "Finished" : "已完成",
    "Later" : "稍後",
    "copy" : "複製",
    "Done" : "完成",
    "The file was uploaded" : "檔案已上傳",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 的限制",
    "No file was uploaded" : "沒有檔案被上傳",
    "Missing a temporary folder" : "找不到暫存資料夾",
    "Could not write file to disk" : "寫入硬碟失敗",
    "A PHP extension stopped the file upload" : "一個 PHP 擴充功能終止檔案的上傳",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck是一種看板式組織工具，旨在針對與Nextcloud集成的團隊進行個人計劃和項目組織。\n\n\n- 📥 增加您的任務到card和把它們整理好\n- 📄 寫下額外的筆記在markdown\n- 🔖 分配標籤以更好地組織\n- 👥 與您的團隊，朋友或家人分享\n- 📎 附加檔案並將其嵌入到您的 markdown 描述\n- 💬 使用評論與您的團隊討論\n- ⚡ 跟踪變化在活動流程中\n- 🚀 取得您的專案組織",
    "Cancel" : "取消",
    "File already exists" : "檔案已存在",
    "Add new list" : "新增清單",
    "Details" : "詳細資料",
    "Sharing" : "分享",
    "Tags" : "標籤",
    "Deleted items" : "刪除的項目",
    "Timeline" : "時間軸",
    "Undo" : "復原",
    "Can edit" : "可以編輯",
    "Can share" : "可以分享",
    "Delete" : "刪除",
    "Delete list" : "刪除清單",
    "Add card" : "增加卡片",
    "Edit" : "編輯",
    "Title" : "標題",
    "Members" : "成員",
    "Assign to users" : "分派給使用者",
    "Due date" : "截止日",
    "Description" : "描述",
    "Attachments" : "附件",
    "Comments" : "意見",
    "Modified" : "已修改",
    "Created" : "已新增",
    "Upload attachment" : "上傳附件",
    "Save" : "儲存",
    "Reply" : "回覆",
    "Update" : "更新",
    "(group)" : "(群組)",
    "seconds ago" : "幾秒前",
    "Assign to me" : "分派給我",
    "Archive card" : "封存卡片",
    "Delete card" : "刪除作業",
    "Move card" : "移動卡片",
    "Shared with you" : "與您分享",
    "Settings" : "設定",
    "Edit board" : "編輯專案",
    "An error occurred" : "發生錯誤",
    "Link to a board" : "連結到佈告欄",
    "Maximum file size of {size} exceeded" : "達到最大的檔案大小 {size} "
},
"nplurals=1; plural=0;");
